@@ -3,19 +3,18 @@ package Search::OpenSearch;
 use warnings;
 use strict;
 use Carp;
-use Class::Load;
 
-our $VERSION = '0.399_05';
+our $VERSION = '0.01';
 
 sub engine {
-    my $class = shift;
-    my %args  = @_;
-    my $type  = delete $args{type} or confess "type required";
-    my $engine_class
-        = $type =~ s/^\+//
-        ? $type
-        : 'Search::OpenSearch::Engine::' . $type;
-    Class::Load::load_class($engine_class);
+    my $class        = shift;
+    my %args         = @_;
+    my $type         = delete $args{type} or croak "type required";
+    my $engine_class = 'Search::OpenSearch::Engine::' . $type;
+    eval "use $engine_class";
+    if ($@) {
+        croak $@;
+    }
     return $engine_class->new(%args);
 }
 
@@ -31,7 +30,7 @@ Search::OpenSearch - provide search results in OpenSearch format
 
  use Search::OpenSearch;
  my $engine = Search::OpenSearch->engine(
-    type    => 'Lucy',
+    type    => 'KSx',
     index   => [qw( path/to/index1 path/to/index2 )],
     facets  => {
         names       => [qw( color size flavor )],
@@ -40,32 +39,28 @@ Search::OpenSearch - provide search results in OpenSearch format
     fields  => [qw( color size flavor )],
  );
  my $response = $engine->search(
-    q   => 'quick brown fox',   # query
-    s   => 'score desc',        # sort order
-    o   => 0,                   # offset
-    p   => 25,                  # page size
-    h   => 1,                   # highlight query terms in results
-    c   => 0,                   # count total only (same as f=0 r=0)
-    L   => 'field|low|high',    # limit results to inclusive range
-    f   => 1,                   # include facets
-    r   => 1,                   # include results
-    t   => 'XML',               # or JSON
-    u   => 'http://yourdomain.foo/opensearch/',
-    b   => 'AND',               # or OR
-    x   => [qw( foo bar )],     # return only a subset of fields
+    q           => 'quick brown fox',   # query
+    s           => 'rank desc',         # sort order
+    o           => 0,                   # offset
+    p           => 25,                  # page size
+    h           => 1,                   # highlight query terms in results
+    c           => 0,                   # return count stats only (no results)
+    L           => 'field|low|high',    # limit results to inclusive range
+    f           => 1,                   # include facets
+    format      => 'XML',               # or JSON
  );
  print $response;
 
 =head1 DESCRIPTION
 
-Search::OpenSearch is a framework for search engines
+Search::OpenSearch is a framework for various backend engines
 to return results comforming to the OpenSearch API (http://opensearch.org/).
 
 =head1 METHODS
 
 =head2 engine( I<args> )
 
-Returns a new L<Search::OpenSearch::Engine> instance.
+Returns a new Search::OpenSearch::Engine instance.
 
 =head1 AUTHOR
 
@@ -77,6 +72,9 @@ Please report any bugs or feature requests to C<bug-search-opensearch at rt.cpan
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Search-OpenSearch>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
