@@ -1,13 +1,10 @@
 package Search::OpenSearch::Facets;
-use Moose;
-use MooseX::StrictConstructor;
-use Types::Standard qw( ArrayRef Int );
+use strict;
+use warnings;
 use Carp;
+use base qw( Rose::ObjectX::CAF );
 
-has 'names' => ( is => 'rw', isa => ArrayRef );
-has 'sample_size' => ( is => 'rw', isa => Int, default => sub {0} );
-
-our $VERSION = '0.399_05';
+__PACKAGE__->mk_accessors(qw( names sample_size ));
 
 1;
 
@@ -31,7 +28,7 @@ Search::OpenSearch::Facets - represents Facet metadata
  );
  my $response = $engine->search(
     q           => 'quick brown fox',   # query
-    s           => 'score desc',        # sort order
+    s           => 'rank desc',         # sort order
     o           => 0,                   # offset
     p           => 25,                  # page size
     h           => 1,                   # highlight query terms in results
