@@ -1,24 +1,28 @@
 package Search::OpenSearch::Response::JSON;
-use Moose;
+use strict;
+use warnings;
 use Carp;
-extends 'Search::OpenSearch::Response';
+use base qw( Search::OpenSearch::Response );
 use JSON;
 
-our $VERSION = '0.399_05';
-
 sub stringify {
-    my $self = shift;
+    my $self    = shift;
+    my $results = $self->fetch_results();
+
+    # TODO more.
+    my %resp = (
+        results   => $results,
+        total     => $self->total,
+        offset    => $self->offset,
+        page_size => $self->page_size,
+    );
 
-    my $resp = $self->as_hash;
-    
     # in devel mode use pretty()
     return $self->debug
-        ? JSON->new->utf8->pretty(1)->encode($resp)
-        : encode_json($resp);
+        ? JSON->new->utf8->pretty(1)->encode( \%resp )
+        : encode_json( \%resp );
 }
 
-sub content_type { return 'application/json; charset=utf-8' }
-
 1;
 
 __END__
@@ -41,14 +45,13 @@ Search::OpenSearch::Response::JSON - provide search results in JSON format
  );
  my $response = $engine->search(
     q           => 'quick brown fox',   # query
-    s           => 'score desc',        # sort order
+    s           => 'rank desc',         # sort order
     o           => 0,                   # offset
     p           => 25,                  # page size
     h           => 1,                   # highlight query terms in results
     c           => 0,                   # return count stats only (no results)
     L           => 'field|low|high',    # limit results to inclusive range
     f           => 1,                   # include facets
-    r           => 1,                   # include results
     format      => 'JSON',              # or XML
  );
  print $response;
@@ -74,10 +77,6 @@ Returns the Response in JSON format.
 
 Response objects are overloaded to call stringify().
 
-=head2 content_type
-
-Returns appropriate MIME type for the format returned by stringify().
-
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
